Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(131)

Unified Diff: chrome/browser/metrics/metrics_memory_details.cc

Issue 2838703003: Stop emitting physical footprint on macOS 10.11. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« base/process/process_metrics_mac.cc ('K') | « base/process/process_metrics_mac.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/metrics/metrics_memory_details.cc
diff --git a/chrome/browser/metrics/metrics_memory_details.cc b/chrome/browser/metrics/metrics_memory_details.cc
index 1ba164c11e5636a809faf41812297d4f6d804727..2b9bc7d3b0a97cfccf26b48d391299c1486db53d 100644
--- a/chrome/browser/metrics/metrics_memory_details.cc
+++ b/chrome/browser/metrics/metrics_memory_details.cc
@@ -176,8 +176,8 @@ void MetricsMemoryDetails::UpdateHistograms() {
continue;
case content::PROCESS_TYPE_GPU:
#if defined(OS_MACOSX)
- // Physical footprint was introduced in macOS 10.11.
- if (base::mac::IsAtLeastOS10_11()) {
+ // Physical footprint was introduced in macOS 10.12.
+ if (base::mac::IsAtLeastOS10_12()) {
UMA_HISTOGRAM_MEMORY_LARGE_MB(
"Memory.Experimental.Gpu.PhysicalFootprint.MacOS",
browser.processes[index].phys_footprint / 1024 / 1024);
« base/process/process_metrics_mac.cc ('K') | « base/process/process_metrics_mac.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698